==> jc-1.4.0.tar.gz: java/security/PermissionCollection.h <==
// public abstract class java.security.PermissionCollection

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_PermissionCollection_H_
#define _JC_java_security_PermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_PermissionCollection$sub_refs	_jc_java_security_PermissionCollection$sub_refs;
typedef struct _jc_java_security_PermissionCollection$sub_nonrefs	_jc_java_security_PermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_PermissionCollection$refs	_jc_java_security_PermissionCollection$refs;
typedef struct _jc_java_security_PermissionCollection$nonrefs	_jc_java_security_PermissionCollection$nonrefs;
typedef struct _jc_java_security_PermissionCollection$object	_jc_java_security_PermissionCollection$object;

typedef struct _jc_java_security_PermissionCollection$fields_struct	_jc_java_security_PermissionCollection$fields_struct;
typedef const struct _jc_java_security_PermissionCollection$vmethods	_jc_java_security_PermissionCollection$vmethods;
typedef const struct _jc_java_security_PermissionCollection$vtable	_jc_java_security_PermissionCollection$vtable;
typedef const struct _jc_java_security_PermissionCollection$vtype	_jc_java_security_PermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_PermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_PermissionCollection$fields_struct _jc_java_security_PermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_PermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_PermissionCollection$object *);

// Virtual methods
extern void _jc_java_security_PermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_object *_jc_java_security_PermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
extern jboolean _jc_java_security_PermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern jboolean _jc_java_security_PermissionCollection$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
extern void _jc_java_security_PermissionCollection$method$setReadOnly$b830e19924e04851(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_PermissionCollection$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_PermissionCollection$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_PermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_PermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_PermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_PermissionCollection$method_info$isReadOnly$c9d2a7ec56d3b05a;
extern _jc_method _jc_java_security_PermissionCollection$method_info$setReadOnly$b830e19924e04851;
extern _jc_method _jc_java_security_PermissionCollection$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_PermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *);
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *);
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
	void	(*setReadOnly$b830e19924e04851)(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_PermissionCollection$object *);
};

// Vtable
struct _jc_java_security_PermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
};

// Vtype
struct _jc_java_security_PermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_PermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_PermissionCollection$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_PermissionCollection$refs {
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_PermissionCollection$sub_nonrefs {
	jboolean	readOnly;
};

// Non-reference instance fields (object)
struct _jc_java_security_PermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
};

// Object instance structure
struct _jc_java_security_PermissionCollection$object {
	_jc_java_security_PermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_PermissionCollection$vtype	*vtype;
	_jc_java_security_PermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_PermissionCollection$vtype _jc_java_security_PermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_PermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_PermissionCollection$class_object;

#endif	/* _JC_java_security_PermissionCollection_H_ */

==> jc-1.4.6.tar.gz: java/security/PermissionCollection.h <==
// public abstract class java.security.PermissionCollection

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_PermissionCollection_H_
#define _JC_java_security_PermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_PermissionCollection$sub_refs	_jc_java_security_PermissionCollection$sub_refs;
typedef struct _jc_java_security_PermissionCollection$sub_nonrefs	_jc_java_security_PermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_PermissionCollection$refs	_jc_java_security_PermissionCollection$refs;
typedef struct _jc_java_security_PermissionCollection$nonrefs	_jc_java_security_PermissionCollection$nonrefs;
typedef struct _jc_java_security_PermissionCollection$object	_jc_java_security_PermissionCollection$object;

typedef struct _jc_java_security_PermissionCollection$fields_struct	_jc_java_security_PermissionCollection$fields_struct;
typedef const struct _jc_java_security_PermissionCollection$vmethods	_jc_java_security_PermissionCollection$vmethods;
typedef const struct _jc_java_security_PermissionCollection$vtable	_jc_java_security_PermissionCollection$vtable;
typedef const struct _jc_java_security_PermissionCollection$vtype	_jc_java_security_PermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_PermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_PermissionCollection$fields_struct _jc_java_security_PermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_PermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_PermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_PermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_PermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_PermissionCollection$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_PermissionCollection$method$setReadOnly$b830e19924e04851(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_PermissionCollection$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_PermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_PermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_PermissionCollection$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_security_PermissionCollection$method_info$isReadOnly$c9d2a7ec56d3b05a;
extern _jc_method _jc_java_security_PermissionCollection$method_info$setReadOnly$b830e19924e04851;
extern _jc_method _jc_java_security_PermissionCollection$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_PermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_PermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
	void	(*setReadOnly$b830e19924e04851)(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_PermissionCollection$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_PermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
};

// Vtype
struct _jc_java_security_PermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_PermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_PermissionCollection$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_PermissionCollection$refs {
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_PermissionCollection$sub_nonrefs {
	jboolean	readOnly;
};

// Non-reference instance fields (object)
struct _jc_java_security_PermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
};

// Object instance structure
struct _jc_java_security_PermissionCollection$object {
	_jc_java_security_PermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_PermissionCollection$vtype	*vtype;
	_jc_java_security_PermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_PermissionCollection$vtype _jc_java_security_PermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_PermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_PermissionCollection$class_object;

#endif	/* _JC_java_security_PermissionCollection_H_ */
